<?php

namespace Drupal\documentation_generator\Plugin\DocumentationGeneratorRender;

use Dompdf\Dompdf;
use Drupal\Core\File\Exception\FileException;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\documentation_generator\Plugin\DocumentationGeneratorRenderBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * PDF Documentation Generator render.
 *
 * Implements Documentation Generator Render plugin for PDF.
 *
 * @DocumentationGeneratorRender(
 *   id = "pdf",
 *   label = @Translation("PDF")
 * )
 */
class PDF extends DocumentationGeneratorRenderBase implements ContainerFactoryPluginInterface {

  /**
   * The mpdf.
   *
   * @var \Dompdf\Dompdf
   */
  protected $dompdf;

  /**
   * Constructs a new PDF instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Dompdf\Dompdf $dompdf
   *   The mpdf.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, Dompdf $dompdf) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->dompdf = $dompdf;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('documentation_generator.dompdf')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getExtension() {
    return 'pdf';
  }

  /**
   * {@inheritdoc}
   */
  public function render($fileName, $path, $title, array $groups) {
    $build = [
      '#theme' => 'documentation',
      '#title' => $title,
      '#groups' => $groups,
    ];

    $this->dompdf->loadHtml(render($build));
    $this->dompdf->render();
    $output = $this->dompdf->output();

    $success = TRUE;
    try {
      file_save_data($output, 'private:// ' . $fileName);
    }
    catch (FileException $e) {
      $success = FALSE;
    }

    return $success;
  }

}
